@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -23,9 +25,9 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/oslo.privsep'
-bug_project = 'oslo.privsep'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/oslo.privsep'
+openstackdocs_bug_project = 'oslo.privsep'
+openstackdocs_bug_tag = ''
 
 # The suffix of source filenames.
 source_suffix = '.rst'
@@ -34,7 +36,6 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'oslo.privsep'
 copyright = u'2014, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
@@ -45,7 +46,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -53,7 +54,6 @@ pygments_style = 'sphinx'
 # Sphinx are currently 'default' and 'sphinxdoc'.
 html_theme = 'openstackdocs'
 
-
 # -- sphinxcontrib.apidoc configuration --------------------------------------
 
 apidoc_module_dir = '../../oslo_privsep'
